#
# spec file for package tvheadend
#
# Copyright (c) 2016 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#


%define htsgroup video
%define htsuser hts
%if 0%{?suse_version} > 1210
%bcond_without  systemd
%else
%bcond_with     systemd
%endif
Name:           tvheadend
Version:        4.0.9
Release:        2.1
Summary:        A TV Streaming Server
License:        GPL-3.0
Group:          Productivity/Multimedia/Other
Url:            https://tvheadend.org/
Source0:        http://github.com/%{name}/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.init
Source2:        %{name}.rpmlintrc
Source3:        %{name}_super
Patch0:         %{name}-4.0_no-werror.patch
# PATCH-FIX-OPENSUSE tvheadend-fix-misleading-indent.patch malcolmlewis@opensuse.org -- Fix warning/error produced with gcc-6.
Patch1:         %{name}-fix-misleading-indent.patch
BuildRequires:  fdupes
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libavcodec) = 56.60.100
BuildRequires:  pkgconfig(libavformat) = 56.40.101
BuildRequires:  pkgconfig(libavresample) = 2.1.0
BuildRequires:  pkgconfig(libavutil) = 54.31.100
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libswscale) = 3.1.101
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with systemd}
%{?systemd_requires}
%endif
%if 0%{?suse_version} > 1140
%if 0%{?suse_version} != 1315
BuildRequires:  pkgconfig(liburiparser)
%endif
%endif

%description
A TV streaming server supporting DVB-S, DVB-S2, DVB-C, DVB-T, ATSC, IPTV,
and Analog video (V4L) as input sources.

It also comes with a powerful and easy to use web interface both used for
configuration and day-to-day operations, such as searching the EPG and
scheduling recordings.

%prep
%setup -q
%if 0%{?suse_version} <= 1140
%patch0
%endif
%if 0%{?suse_version} >= 1320
%patch1 -p1
%endif

sed -e "s/-u \([^ ]*\) -g \([^ ]*\)/-u %{htsuser} -g %{htsgroup}/" -i rpm/%{name}.sysconfig
sed -e '/^TVH_ARGS/cTVH_ARGS="-C"' -i debian/%{name}.default
echo %{version} > rpm/version

%build
%configure --disable-dvbscan \
           --disable-libffmpeg_static \
	   --disable-libffmpeg_static_x264 \
	   --disable-hdhomerun_static
make V=1 %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}%{_localstatedir}/adm/fillup-templates/
mkdir -p %{buildroot}%{_sbindir}
%if %{with systemd}
install -D -m 644 rpm/%{name}.service %{buildroot}/%{_unitdir}/%{name}.service
install -m 644 rpm/%{name}.sysconfig %{buildroot}/%{_localstatedir}/adm/fillup-templates/sysconfig.%{name}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%else
install -D -m 744 %{SOURCE1} %{buildroot}%{_initddir}/%{name}
install -m 644 debian/%{name}.default %{buildroot}/%{_localstatedir}/adm/fillup-templates/sysconfig.%{name}
ln -s %{_initddir}/%{name} %{buildroot}%{_sbindir}/rc%{name}
%endif
# Install superuser helper script
install -Dm0755 %{S:3} %{buildroot}%{_sbindir}/%{name}_super
%fdupes -s %{buildroot}%{_datadir}
chmod -x %{buildroot}%{_mandir}/man1/tvheadend.1

%post
%if %{with systemd}
%fillup_only %{name}
%service_add_post %{name}.service
%else
%fillup_and_insserv %{name}
%endif
cat << 'EOM'
  ==> IMPORTANT: Post configuration tasks;
  ==> 1. Start the tvheadend service (to create home directory).
  ==> 2. Run tvheadend_super to set default username and password.
  ==> 3. Restart tvheadend service.
  ==>
  ==>
  ==> All further configuration is maintained through the web interface:
  ==>
  ==> http://localhost:9981/
  ==>
EOM

%pre
%if %{with systemd}
%service_add_pre %{name}.service
%endif
%{_sbindir}/useradd -u 1337 -g %{htsgroup} -m -s /bin/false %{htsuser} -c "Tvheadend TV server" &> /dev/null || :
%{_sbindir}/passwd -l %{htsuser} &> /dev/null || :

%preun
%if %{with systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal %{name}
%endif

%postun
%if %{with systemd}
%service_del_postun %{name}.service
%else
%restart_on_update %{name}
%insserv_cleanup
%endif

%files
%defattr(-,root,root)
%doc CONTRIBUTING.md LICENSE.md
%{_bindir}/tvheadend
%{_datadir}/tvheadend
%{_mandir}/man1/tvheadend.1%{?ext_man}
%if %{with systemd}
%{_unitdir}/%{name}.service
%else
%{_initddir}/%{name}
%endif
%{_localstatedir}/adm/fillup-templates/sysconfig.%{name}
%{_sbindir}/%{name}_super
%{_sbindir}/rc%{name}

%changelog
* Mon Sep 26 2016 malcolmlewis@opensuse.org
- Add tvheadend-fix-misleading-indent.patch: Fix warning/error
  produced with gcc-6.
* Sat Apr  9 2016 malcolmlewis@opensuse.org
- Update to version 4.0.9:
  + https://github.com/tvheadend/tvheadend/compare/v4.0.8...v4.0.9.
- Disable hdhomerun client and static build.
* Sun Feb  7 2016 malcolmlewis@opensuse.org
- Update to version 4.0.8:
  + Changelog on
    https://github.com/tvheadend/tvheadend/compare/v4.0.7...v4.0.8.
- Fix incorrect sed command in spec file to add user hts and video
  group to /etc/sysconfig/tvheadend file.
- Add %%%%doc files.
- Delete source file not bzipped from rpmlintrc file.
- Add helper script to add/update superuser file.
- Update post install message to include post install steps.
* Tue Oct 27 2015 malcolmlewis@opensuse.org
- Update to version 4.0.7:
  + Changelog on
    https://tvheadend.org/projects/tvheadend/wiki/Tvheadend-40.
* Fri Jun 26 2015 aloisio@gmx.com
- Update to version 4.0.5
  * changelog on https://tvheadend.org/projects/tvheadend/wiki/Tvheadend-40
- Added init support for 11.4/SLE_11
- spec cleanup
* Sat Jun  8 2013 p.drouand@gmail.com
- Update to version 3.4
- Clean and rebase specfile
- Add systemd service file to start automatically tvheadend daemon
  and add tvheadend to video group to get it usable by user
- Remove dvb-scan tables archive and pass --disable-dvbscan;
  It doesn't work correctly and is actually obsolete
- Remove tvheadend-3.2.18-dvbscan_data.patch; it's not needed anymore
- Fix executable manpage
* Sat Feb  2 2013 hvogel@opensuse.org
- Update to version 3.2.18
* Tue Mar 27 2012 hvogel@opensuse.org
- Don't build with Werror
- Add summary/description
* Fri Apr 22 2011 hvogel@opensuse.org
- Initial package, version 2.12
